==> wmc_personalized_plugin-1.1.4.tar.gz: android/src/main/java/com/synergy/wmc/wmc_personalized_plugin/WmcPersonalizedPlugin.java <==
package com.synergy.wmc.wmc_personalized_plugin;

import android.content.Context;

import androidx.annotation.NonNull;

import java.util.Date;
import java.util.Map;
import android.os.StrictMode;

import io.flutter.app.FlutterApplication;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import android.util.Log;

/** WmcPersonalizedPlugin */
public class WmcPersonalizedPlugin implements FlutterPlugin, MethodCallHandler {
  
  private Context mContext;
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "wmc_personalized_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onDetachedFromEngine(FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "wmc_personalized_plugin");
    channel.setMethodCallHandler(this);
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "wmc_personalized_plugin");
    channel.setMethodCallHandler(new WmcPersonalizedPlugin());
  }


  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    //System.out.println(mContext);
    if (android.os.Build.VERSION.SDK_INT > 9) {
      StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
      StrictMode.setThreadPolicy(policy);
    }

    if (call.method.equals("initialize")) {
      String apiKey = call.argument("apiKey");
      final Long now = new Date().getTime();

      ApiWmcModule.initialize(mContext,apiKey, new ResultInitListener() {
        @Override
        public void onSuccess(String data) {
          Long finished = new Date().getTime() - now;
          System.out.println("timeExecute initialize: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          System.out.println("onError initialize: "+finished+" miliseconds");
          result.error(error,message,e);
        }
      });
    }  else if (call.method.equals("session")) {
      final Long now = new Date().getTime();
      ApiWmcModule.getSession(mContext, new ResultInitListener() {
        @Override
        public void onSuccess(String data) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/getSession","timeExecute session: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/getSession","onError session: "+finished+" miliseconds");
          result.error(error,message,e);
        }
      });

    } else if (call.method.equals("request")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");
      String method = call.argument("method");
      Map<String,String> options = call.argument("options");
      Map<String,String>  data = call.argument("data");

      final Long now = new Date().getTime();
      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);


      ApiWmcModule.request(mContext,session, uri, method, options, data, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          Long finished = new Date().getTime() - now;
          System.out.println("timeExecute request: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          System.out.println("onError request: "+finished+" miliseconds");
          result.error(error,message,e);
        }
      });

    } else if (call.method.equals("post")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");
      Map<String,String> options = call.argument("options");
      String data = call.argument("data");

      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);

      final Long now = new Date().getTime();

      ApiWmcModule.post(mContext,session, uri, options, data, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          Long finished = new Date().getTime() - now;
          System.out.println("timeExecute post: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          System.out.println("onError post: "+finished+" miliseconds");
          result.error(error,message,e);
        }
      });

    }else if (call.method.equals("put")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");
      Map<String,String> options = call.argument("options");
      String data = call.argument("data");

      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);

      final Long now = new Date().getTime();

      ApiWmcModule.put(mContext,session, uri, options, data, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          Long finished = new Date().getTime() - now;
          System.out.println("timeExecute put: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          System.out.println("onError put: "+finished+" miliseconds");
          result.error(error,message,e);
        }
      });

    }else if (call.method.equals("resource")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");

      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);

      final Long now = new Date().getTime();

      ApiWmcModule.getResource(mContext,session, uri, new ResultRequestDataListener() {
        @Override
        public void onSuccess(byte[] data) {
          Long finished = new Date().getTime() - now;
          System.out.println("timeExecute resource: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          System.out.println("onError resource: "+finished+" miliseconds");
          result.error(error,message,e);
        }
      });

    }else if(call.method.equals("connectionData")){

      ApiWmcModule.connectionData(mContext, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          result.error(error,message,e);
        }
      });

    }else{
      result.notImplemented();
    }
  }
}

==> wmc_personalized_plugin-1.1.6.tar.gz: android/src/main/java/com/synergy/wmc/wmc_personalized_plugin/WmcPersonalizedPlugin.java <==
package com.synergy.wmc.wmc_personalized_plugin;

import android.content.Context;

import androidx.annotation.NonNull;

import java.util.Date;
import java.util.Map;
import android.os.StrictMode;

import io.flutter.app.FlutterApplication;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import android.util.Log;

/** WmcPersonalizedPlugin */
public class WmcPersonalizedPlugin implements FlutterPlugin, MethodCallHandler {
  
  private Context mContext;
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "wmc_personalized_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onDetachedFromEngine(FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "wmc_personalized_plugin");
    channel.setMethodCallHandler(this);
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "wmc_personalized_plugin");
    channel.setMethodCallHandler(new WmcPersonalizedPlugin());
  }


  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    //System.out.println(mContext);
    if (android.os.Build.VERSION.SDK_INT > 9) {
      StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
      StrictMode.setThreadPolicy(policy);
    }

    if (call.method.equals("initialize")) {
      String apiKey = call.argument("apiKey");
      final Long now = new Date().getTime();

      ApiWmcModule.initialize(mContext,apiKey, new ResultInitListener() {
        @Override
        public void onSuccess(String data) {
          Long finished = new Date().getTime() - now; 
          Log.e("ApiWMC/Initialize","timeExecute Initialize: "+finished+" miliseconds"); 
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/Initialize/onError","timeExecute Initialize: "+finished+" miliseconds");  
          result.error(error,message,e);
        }
      });
    }  else if (call.method.equals("session")) {
      final Long now = new Date().getTime();
      ApiWmcModule.getSession(mContext, new ResultInitListener() {
        @Override
        public void onSuccess(String data) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/getSession","timeExecute session: "+finished+" miliseconds");
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) { 
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/getSession/onError","timeExecute session: "+finished+" miliseconds");  
          result.error(error,message,e);
        }
      });

    } else if (call.method.equals("request")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");
      String method = call.argument("method");
      Map<String,String> options = call.argument("options");
      Map<String,String>  data = call.argument("data");

      final Long now = new Date().getTime();
      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);


      ApiWmcModule.request(mContext,session, uri, method, options, data, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          Long finished = new Date().getTime() - now; 
          Log.e("ApiWMC/request","timeExecute request: "+finished+" miliseconds"); 
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now; 
          Log.e("ApiWMC/request","timeExecute request: "+finished+" miliseconds"); 
          result.error(error,message,e);
        }
      });

    } else if (call.method.equals("post")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");
      Map<String,String> options = call.argument("options");
      String data = call.argument("data");

      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);

      final Long now = new Date().getTime();

      ApiWmcModule.post(mContext,session, uri, options, data, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/post","timeExecute post: "+finished+" miliseconds");  
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/post/onError","timeExecute post: "+finished+" miliseconds");  
          result.error(error,message,e);
        }
      });

    }else if (call.method.equals("put")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");
      Map<String,String> options = call.argument("options");
      String data = call.argument("data");

      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);

      final Long now = new Date().getTime();

      ApiWmcModule.put(mContext,session, uri, options, data, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/put","timeExecute put: "+finished+" miliseconds");   
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/put/onError","timeExecute put: "+finished+" miliseconds");  
          result.error(error,message,e);
        }
      });

    }else if (call.method.equals("resource")) {
      String uri = call.argument("uri");
      String jsonSession = call.argument("session");

      Gson gson = new Gson();
      Session session = gson.fromJson(jsonSession, Session.class);

      final Long now = new Date().getTime();

      ApiWmcModule.getResource(mContext,session, uri, new ResultRequestDataListener() {
        @Override
        public void onSuccess(byte[] data) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/getResource","timeExecute getResource: "+finished+" miliseconds");   
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          Long finished = new Date().getTime() - now;
          Log.e("ApiWMC/getResource/onError","timeExecute getResource: "+finished+" miliseconds");  
          result.error(error,message,e);
        }
      });

    }else if(call.method.equals("connectionData")){

      ApiWmcModule.connectionData(mContext, new ResultRequestListener() {
        @Override
        public void onSuccess(Map<String,String> data) {
          result.success(data);
        }

        @Override
        public void onError(String error, String message, Exception e) {
          result.error(error,message,e);
        }
      });

    }else{
      result.notImplemented();
    }
  }
}
